@@ -1,21 +1,31 @@
-//--------------------------------------------------------------------------
-// Program to pull the information out of various types of EFIF digital 
-// camera files and show it in a reasonably consistent way
-//
-// This module parses the very complicated exif structures.
-//
-// Matthias Wandel,  Dec 1999 - August 2000
-//--------------------------------------------------------------------------
+/***************************************************************************
+                          exif.cpp  -  description
+                             -------------------
+    begin                : Dec 1999
+    copyright            : (C) 1999 by Matthias Wandel, 2000 by Richard Groult
+    email                : mwandel@sentex.net  rgroult@jalix.org 
+ ***************************************************************************/
+
+/***************************************************************************
+ *                                                                         *
+ *   This program is free software; you can redistribute it and/or modify  *
+ *   it under the terms of the GNU General Public License as published by  *
+ *   the Free Software Foundation; either version 2 of the License, or     *
+ *   (at your option) any later version.                                   *
+ *                                                                         *
+ ***************************************************************************/
+
 
 #include "exif.h"
 
+
 static unsigned char * LastExifRefd;
 static int ExifSettingsLength;
 static double FocalplaneXRes;
 static double FocalplaneUnits;
 static int ExifImageWidth;
 static int MotorolaOrder = 0;
-static char * ApplyCommand = NULL;  // Apply this command to all images.
+//static char * ApplyCommand = NULL;  // Apply this command to all images.
 static char * ExifSourceName = NULL;// Extract Exif header from this file, and
 static int FilesMatched;
 static int TrimExif = FALSE;	    // Cut off exif beyond interesting data.
@@ -23,8 +33,7 @@ static int DeleteComments = FALSE;
 static int ShowConcise  = FALSE;
 static int DoAction	= FALSE;
 static Section_t Sections[MAX_SECTIONS];
-static char * ThumbnailName = NULL; // If not NULL, use this string to make up
-				  // the filename to store the thumbnail to.
+
  //Command line parsing code
 static const char * progname;	// program name for error messages
 static char * FilterModel = NULL;
@@ -36,10 +45,12 @@ static int HaveAll;
 static const char * CurrentFile;
 static ImageInfo_t ImageInfo;
 static int ShowTags;
+//static char * ThumbnailName = NULL; // If not NULL, use this string to make up
+				  // the filename to store the thumbnail to.
 
 typedef struct {
     unsigned short Tag;
-    char * Desc;
+    const char * Desc;
 }TagTable_t;
 //--------------------------------------------------------------------------
 // Table of Jpeg encoding process names
@@ -229,7 +240,7 @@ static TagTable_t TagTable[] = {
 //--------------------------------------------------------------------------
 // Error exit handler
 //--------------------------------------------------------------------------
-void ErrExit(char * msg)
+void ErrExit(const char * msg)
 {
     fprintf(stderr,"Error : %s\n", msg);
 }
@@ -310,6 +321,7 @@ static void DiscardAllButExif(void)
 //--------------------------------------------------------------------------
 // Apply the specified command to the jpeg file.
 //--------------------------------------------------------------------------
+/*
 static void DoCommand(const char * FileName)
 {
     int a,e;
@@ -373,6 +385,7 @@ static void DoCommand(const char * FileName)
         }
     }
 }
+*/
 //--------------------------------------------------------------------------
 // Subsititute original name for '&i' if present in specified name.
 // This to allow specifying relative names when manipulating multiple files.
@@ -771,6 +784,7 @@ static void ProcessExifDir(unsigned char * DirStart, unsigned char * OffsetBase,
 
     if ((DirStart+2+NumDirEntries*12) > (OffsetBase+ExifLength)){
         ErrExit("Illegally sized directory");
+	return;
     }
 
     if (ShowTags){
@@ -908,7 +922,7 @@ static void ProcessExifDir(unsigned char * DirStart, unsigned char * OffsetBase,
                 // have appropriate aperture information yet.
                 if (ImageInfo.ApertureFNumber == 0){
                     ImageInfo.ApertureFNumber 
-                        = (float)exp(ConvertAnyFormat(ValuePtr, Format)*log(2)*0.5);
+                        = (float)exp(ConvertAnyFormat(ValuePtr, Format)*log(2.0)*0.5);
                 }
                 break;
 
@@ -935,7 +949,7 @@ static void ProcessExifDir(unsigned char * DirStart, unsigned char * OffsetBase,
                 // this value if we don't already have it from somewhere else.
                 if (ImageInfo.ExposureTime == 0){
                     ImageInfo.ExposureTime 
-                        = (float)(1/exp(ConvertAnyFormat(ValuePtr, Format)*log(2)));
+                        = (float)(1/exp(ConvertAnyFormat(ValuePtr, Format)*log(2.0)));
                 }
                 break;
 
@@ -1459,7 +1473,7 @@ void ShowConciseImageInfo(void)
 //--------------------------------------------------------------------------
 // Do selected operations to one file at a time.
 //--------------------------------------------------------------------------
-QString ProcessFile(const char * FileName)
+QString ProcessFile(const char * FileName, bool showsize, const char *ThumbnailName)
 {
     QString ret;
     
@@ -1489,6 +1503,8 @@ QString ProcessFile(const char * FileName)
 
     strncpy(ImageInfo.FileName, FileName, _MAX_PATH);
 
+
+
    if (ExifSourceName){
         char RelativeExifName[_MAX_PATH+1];
 
@@ -1512,6 +1528,14 @@ QString ProcessFile(const char * FileName)
     }
 
     if (!ReadJpegFile(FileName, ReadMode)) return QString();
+    
+    if(showsize)
+    {
+    	ret= QString().sprintf("%dx%d", ImageInfo.Width, ImageInfo.Height);
+	DiscardData();
+	return ret;
+    }
+
 
     if (CheckFileSkip()){
         DiscardData();
@@ -1535,15 +1559,21 @@ QString ProcessFile(const char * FileName)
             RelativeName(OutFileName, ThumbnailName, FileName);
 
             ThumbnailFile = fopen(OutFileName,"wb");
-            if (ThumbnailFile){
+            if (ThumbnailFile)
+	    {
                 fwrite(ImageInfo.ThumbnailPointer, ImageInfo.ThumbnailSize ,1, ThumbnailFile);
                 fclose(ThumbnailFile);
-                printf("Created: '%s'\n", OutFileName);
-            }else{
+                //printf("Created: '%s'\n", OutFileName);
+		ret="OK";
+            }
+	    else
+	    {
                 ErrExit("Could not write thumbnail file");
             }
-        }else{
-            printf("Image '%s' contains no thumbnail\n",FileName);
+        }else
+	{
+            //printf("Image '%s' contains no thumbnail\n",FileName);
+	    ret="ERROR";
         }
     }
 
