@@ -1,21 +1,30 @@
+/***************************************************************************
+                          printImageDialog.h  -  description
+                             -------------------
+    begin                : Sat Dec 1 2001
+    copyright            : (C)2001 - Andrew Richards
+    email                : ajr@users.sourceforge.net 
+ ***************************************************************************/
+
+/***************************************************************************
+ *                                                                         *
+ *   This program is free software; you can redistribute it and/or modify  *
+ *   it under the terms of the GNU General Public License as published by  *
+ *   the Free Software Foundation; either version 2 of the License, or     *
+ *   (at your option) any later version.                                   *
+ *                                                                         *
+ ***************************************************************************/
+
 #ifndef __PRINT_IMAGE_DIALOG_H__
 #define __PRINT_IMAGE_DIALOG_H__
 
-//
-// Copyright (c) 2000-2001 - Andrew Richards <ajr@users.sourceforge.net>
-//
-// This file is part of the PikView image viewer released under the GNU GPL.
-// For license details see the file COPYING included with this distribution.
-//
-
-
 #include <qprintdialog.h>
 #include <qprinter.h>
 #include <qpixmap.h>
 #include <qrect.h>
 #include <qpushbutton.h>
 #include <qstring.h>
-#include <kapp.h>
+#include <kapplication.h>
 #if KDE_VERSION > 220
 #include <kprinter.h>
 #endif
@@ -26,7 +35,7 @@
 
 class printImageDialog : public KDialog
 {
-	Q_OBJECT;
+	Q_OBJECT
 
 public:
 	/**
